pub enum Resource {
Goal(Goal),
Plan(Plan),
Capability(Capability),
Binding(Binding),
Execution(Execution),
Gate(Gate),
}Expand description
Resource is an enum that can hold any PlanSpec resource type.
Uses untagged serialization since each resource type has its own kind field.
Variants
Goal(Goal)
A Goal resource.
Plan(Plan)
A Plan resource.
Capability(Capability)
A Capability resource.
Binding(Binding)
A Binding resource.
Execution(Execution)
An Execution resource.
Gate(Gate)
A Gate resource.
Implementations
Sourceimpl Resource
impl Resource
Sourcepub fn metadata(&self) -> &ObjectMeta
pub fn metadata(&self) -> &ObjectMeta
Get the metadata of this resource.
Sourcepub fn metadata_mut(&mut self) -> &mut ObjectMeta
pub fn metadata_mut(&mut self) -> &mut ObjectMeta
Get a mutable reference to the metadata of this resource.
Sourcepub fn api_version(&self) -> &str
pub fn api_version(&self) -> &str
Get the API version of this resource.